@@ -24,6 +24,7 @@ import (
 	"time"
 
 	"github.com/coreos/go-semver/semver"
+	"github.com/rs/zerolog"
 	"github.com/rs/zerolog/log"
 	vfs "github.com/twpayne/go-vfs/v4"
 	"go.uber.org/multierr"
@@ -75,6 +76,7 @@ type SourceState struct {
 	encryption              Encryption
 	ignore                  *patternSet
 	interpreters            map[string]*Interpreter
+	logger                  *zerolog.Logger
 	minVersion              semver.Version
 	mode                    Mode
 	defaultTemplateDataFunc func() map[string]interface{}
@@ -126,6 +128,13 @@ func WithInterpreters(interpreters map[string]*Interpreter) SourceStateOption {
 	}
 }
 
+// WithLogger sets the logger.
+func WithLogger(logger *zerolog.Logger) SourceStateOption {
+	return func(s *SourceState) {
+		s.logger = logger
+	}
+}
+
 // WithMode sets the mode.
 func WithMode(mode Mode) SourceStateOption {
 	return func(s *SourceState) {
@@ -193,6 +202,7 @@ func NewSourceState(options ...SourceStateOption) *SourceState {
 		umask:                Umask,
 		encryption:           NoEncryption{},
 		ignore:               newPatternSet(),
+		logger:               &log.Logger,
 		readTemplateData:     true,
 		priorityTemplateData: make(map[string]interface{}),
 		userTemplateData:     make(map[string]interface{}),
@@ -475,7 +485,7 @@ func (s *SourceState) Apply(targetSystem, destSystem System, persistentState Per
 		return err
 	}
 
-	switch skip, err := targetStateEntry.SkipApply(persistentState); {
+	switch skip, err := targetStateEntry.SkipApply(persistentState, targetAbsPath); {
 	case err != nil:
 		return err
 	case skip:
@@ -624,11 +634,11 @@ func (s *SourceState) ExecuteTemplateData(name string, data []byte) ([]byte, err
 		defer delete(chezmoiTemplateData, "sourceFile")
 	}
 
-	var sb strings.Builder
-	if err = tmpl.ExecuteTemplate(&sb, name, templateData); err != nil {
+	builder := strings.Builder{}
+	if err = tmpl.ExecuteTemplate(&builder, name, templateData); err != nil {
 		return nil, err
 	}
-	return []byte(sb.String()), nil
+	return []byte(builder.String()), nil
 }
 
 // Ignored returns if targetRelPath is ignored.
@@ -922,7 +932,7 @@ func (s *SourceState) TemplateData() map[string]interface{} {
 
 // addExternal adds external source entries to s.
 func (s *SourceState) addExternal(sourceAbsPath AbsPath) error {
-	parentAbsPath, name := sourceAbsPath.Split()
+	parentAbsPath, _ := sourceAbsPath.Split()
 
 	parentRelPath, err := parentAbsPath.TrimDirPrefix(s.sourceDirAbsPath)
 	if err != nil {
@@ -931,8 +941,7 @@ func (s *SourceState) addExternal(sourceAbsPath AbsPath) error {
 	parentSourceRelPath := NewSourceRelDirPath(parentRelPath)
 	parentTargetSourceRelPath := parentSourceRelPath.TargetRelPath(s.encryption.EncryptedSuffix())
 
-	suffix := mustTrimPrefix(string(name), externalName+".")
-	format, ok := Formats[suffix]
+	format, ok := Formats[strings.TrimPrefix(sourceAbsPath.Ext(), ".")]
 	if !ok {
 		return fmt.Errorf("%s: unknown format", sourceAbsPath)
 	}
@@ -963,7 +972,7 @@ func (s *SourceState) addPatterns(patternSet *patternSet, sourceAbsPath AbsPath,
 	}
 	dir := sourceRelPath.Dir().TargetRelPath("")
 	scanner := bufio.NewScanner(bytes.NewReader(data))
-	var lineNumber int
+	lineNumber := 0
 	for scanner.Scan() {
 		lineNumber++
 		text := scanner.Text()
@@ -992,9 +1001,7 @@ func (s *SourceState) addPatterns(patternSet *patternSet, sourceAbsPath AbsPath,
 
 // addTemplateData adds all template data in sourceAbsPath to s.
 func (s *SourceState) addTemplateData(sourceAbsPath AbsPath) error {
-	_, name := sourceAbsPath.Split()
-	suffix := mustTrimPrefix(string(name), dataName+".")
-	format, ok := Formats[suffix]
+	format, ok := Formats[strings.TrimPrefix(sourceAbsPath.Ext(), ".")]
 	if !ok {
 		return fmt.Errorf("%s: unknown format", sourceAbsPath)
 	}
@@ -1013,10 +1020,9 @@ func (s *SourceState) addTemplateData(sourceAbsPath AbsPath) error {
 // addTemplatesDir adds all templates in templateDir to s.
 func (s *SourceState) addTemplatesDir(templatesDirAbsPath AbsPath) error {
 	return WalkDir(s.system, templatesDirAbsPath, func(templateAbsPath AbsPath, info fs.FileInfo, err error) error {
-		if err != nil {
-			return err
-		}
 		switch {
+		case err != nil:
+			return err
 		case info.Mode().IsRegular():
 			contents, err := s.system.ReadFile(templateAbsPath)
 			if err != nil {
@@ -1105,7 +1111,7 @@ func (s *SourceState) getExternalDataRaw(ctx context.Context, externalRelPath Re
 		return nil, err
 	}
 	resp, err := http.DefaultClient.Do(req)
-	log.Err(err).
+	s.logger.Err(err).
 		Str("method", req.Method).
 		Int("statusCode", resp.StatusCode).
 		Str("status", resp.Status).
@@ -1184,21 +1190,31 @@ func (s *SourceState) newSourceStateDir(sourceRelPath SourceRelPath, dirAttr Dir
 // newCreateTargetStateEntryFunc returns a targetStateEntryFunc that returns a
 // file with sourceLazyContents if the file does not already exist, or returns
 // the actual file's contents unchanged if the file already exists.
-func (s *SourceState) newCreateTargetStateEntryFunc(fileAttr FileAttr, sourceLazyContents *lazyContents) targetStateEntryFunc {
+func (s *SourceState) newCreateTargetStateEntryFunc(sourceRelPath SourceRelPath, fileAttr FileAttr, sourceLazyContents *lazyContents) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
-		contents, err := destSystem.ReadFile(destAbsPath)
-		switch {
+		var lazyContents *lazyContents
+		switch contents, err := destSystem.ReadFile(destAbsPath); {
 		case err == nil:
+			lazyContents = newLazyContents(contents)
 		case errors.Is(err, fs.ErrNotExist):
-			contents, err = sourceLazyContents.Contents()
-			if err != nil {
-				return nil, err
-			}
+			lazyContents = newLazyContentsFunc(func() ([]byte, error) {
+				contents, err = sourceLazyContents.Contents()
+				if err != nil {
+					return nil, err
+				}
+				if fileAttr.Template {
+					contents, err = s.ExecuteTemplateData(sourceRelPath.String(), contents)
+					if err != nil {
+						return nil, err
+					}
+				}
+				return contents, nil
+			})
 		default:
 			return nil, err
 		}
 		return &TargetStateFile{
-			lazyContents: newLazyContents(contents),
+			lazyContents: lazyContents,
 			empty:        true,
 			perm:         fileAttr.perm() &^ s.umask,
 		}, nil
@@ -1336,8 +1352,8 @@ func (s *SourceState) newScriptTargetStateEntryFunc(sourceRelPath SourceRelPath,
 		return &TargetStateScript{
 			lazyContents: newLazyContentsFunc(contentsFunc),
 			name:         targetRelPath,
+			condition:    fileAttr.Condition,
 			interpreter:  interpreter,
-			once:         fileAttr.Once,
 		}, nil
 	}
 }
@@ -1386,7 +1402,7 @@ func (s *SourceState) newSourceStateFile(sourceRelPath SourceRelPath, fileAttr F
 	var targetStateEntryFunc targetStateEntryFunc
 	switch fileAttr.Type {
 	case SourceFileTypeCreate:
-		targetStateEntryFunc = s.newCreateTargetStateEntryFunc(fileAttr, sourceLazyContents)
+		targetStateEntryFunc = s.newCreateTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents)
 	case SourceFileTypeFile:
 		targetStateEntryFunc = s.newFileTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents)
 	case SourceFileTypeModify:
