@@ -24,7 +24,6 @@ import (
 
 	"github.com/coreos/go-semver/semver"
 	"github.com/google/go-github/v39/github"
-	"github.com/rs/zerolog/log"
 	"github.com/spf13/cobra"
 	vfs "github.com/twpayne/go-vfs/v4"
 	"golang.org/x/sys/unix"
@@ -189,7 +188,7 @@ func (c *Config) runUpgradeCmd(cmd *cobra.Command, args []string) error {
 	// Execute the new version.
 	arg0 := path
 	argv := []string{arg0, "--version"}
-	log.Info().
+	c.logger.Info().
 		Str("arg0", arg0).
 		Strs("argv", argv).
 		Msg("exec")
@@ -230,7 +229,7 @@ func (c *Config) downloadURL(ctx context.Context, url string) ([]byte, error) {
 		return nil, err
 	}
 	resp, err := http.DefaultClient.Do(req)
-	log.Err(err).
+	c.logger.Err(err).
 		Str("method", req.Method).
 		Int("statusCode", resp.StatusCode).
 		Str("status", resp.Status).
@@ -259,13 +258,11 @@ func (c *Config) getLibc() (string, error) {
 	// writes to stdout and exits with code 0. On musl libc systems it writes to
 	// stderr and exits with code 1.
 	lddCmd := exec.Command("ldd", "--version")
-	if output, _ := c.baseSystem.IdempotentCmdCombinedOutput(lddCmd); len(output) != 0 {
-		switch {
-		case libcTypeGlibcRx.Match(output):
-			return libcTypeGlibc, nil
-		case libcTypeMuslRx.Match(output):
-			return libcTypeMusl, nil
-		}
+	switch output, _ := c.baseSystem.IdempotentCmdCombinedOutput(lddCmd); {
+	case libcTypeGlibcRx.Match(output):
+		return libcTypeGlibc, nil
+	case libcTypeMuslRx.Match(output):
+		return libcTypeMusl, nil
 	}
 
 	// Second, try getconf GNU_LIBC_VERSION.
@@ -303,19 +300,18 @@ func (c *Config) replaceExecutable(ctx context.Context, executableFilenameAbsPat
 	}
 
 	// Extract the executable from the archive.
-	gzipr, err := gzip.NewReader(bytes.NewReader(data))
+	gzipReader, err := gzip.NewReader(bytes.NewReader(data))
 	if err != nil {
 		return err
 	}
-	defer gzipr.Close()
-	tr := tar.NewReader(gzipr)
+	defer gzipReader.Close()
+	tarReader := tar.NewReader(gzipReader)
 	var executableData []byte
 FOR:
 	for {
-		h, err := tr.Next()
-		switch {
-		case err == nil && h.Name == c.upgrade.repo:
-			executableData, err = io.ReadAll(tr)
+		switch header, err := tarReader.Next(); {
+		case err == nil && header.Name == c.upgrade.repo:
+			executableData, err = io.ReadAll(tarReader)
 			if err != nil {
 				return err
 			}
